@@ -3,6 +3,17 @@
 """Examp Parabole Mirror Shift"""
 
 import numpy as np
+import pkg_resources
+required = {'KrakenOS'}
+installed = {pkg.key for pkg in pkg_resources.working_set}
+missing = required - installed
+
+if missing:
+    print("No instalado")
+    import sys
+    sys.path.append("../..")
+
+
 import KrakenOS as Kos
 
 # ______________________________________#
